/*
 * Example for DC Motor 4 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration FT900x :
 *  MCU           :        FT900
 *  Dev. Board    :        EasyFT90x
 *  SW            :        mikroC PRO for FT90x v2.2.1
 *
 * Description :
 *
 * This example shows basic controls of DC motor using DC motor 4 click.
 * It shows forward and reverse movement, and high and low rotation speed.
 *
 ******************************************************************************/

#include <stdint.h>

uint16_t pwmPeriod;
sbit DIR_PIN at GPIO_PIN9_bit;

/*
 * System Initialization
 */
void systemInit()
{
    GPIO_Digital_Output( &GPIO_PORT_08_15, _GPIO_PINMASK_1);
    pwmPeriod = PWM_Init(1000);                                   // Set PWM frequency/period (according to the DC motor characteristics)
}

void main()
{

    systemInit();

    while (1)
    {
        //Forward
        DIR_PIN = 0;
        //Forward fast
        PWM_ConfigChannel(pwmPeriod,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0);
        PWM_EnableOutput();
        Delay_ms (3000);
        //Forward slow
        PWM_ConfigChannel(pwmPeriod/2,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0);
        PWM_EnableOutput();
        Delay_ms (3000);
        //Reverse
        DIR_PIN = 1;
        //Reverse fast
        PWM_ConfigChannel(pwmPeriod,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0);
        PWM_EnableOutput();
        Delay_ms (3000);
        //Reverse slow
        PWM_ConfigChannel(pwmPeriod/2,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0); 
        PWM_EnableOutput();
        Delay_ms (3000);
    }
}
/************************************************************ END OF FILE *****/